@@ -44,10 +44,10 @@ t.test('basic', function (t) {
       name: '@foo/bar',
       escapedName: '@foo%2fbar',
       scope: '@foo',
-      rawSpec: '',
+      rawSpec: '*',
       saveSpec: null,
-      fetchSpec: 'latest',
-      type: 'tag',
+      fetchSpec: '*',
+      type: 'range',
     },
 
     '@foo/bar@': {
@@ -55,10 +55,10 @@ t.test('basic', function (t) {
       name: '@foo/bar',
       escapedName: '@foo%2fbar',
       scope: '@foo',
-      rawSpec: '',
+      rawSpec: '*',
       saveSpec: null,
-      fetchSpec: 'latest',
-      type: 'tag',
+      fetchSpec: '*',
+      type: 'range',
     },
 
     '@foo/bar@baz': {
@@ -113,11 +113,11 @@ t.test('basic', function (t) {
         registry: true,
         name: 'bar',
         escapedName: 'bar',
-        type: 'tag',
+        type: 'range',
         raw: 'bar',
-        rawSpec: '',
+        rawSpec: '*',
         saveSpec: null,
-        fetchSpec: 'latest',
+        fetchSpec: '*',
       },
     },
 
@@ -366,10 +366,10 @@ t.test('basic', function (t) {
       name: 'git',
       type: 'alias',
       subSpec: {
-        type: 'tag',
+        type: 'range',
         registry: true,
         name: 'not-git',
-        fetchSpec: 'latest',
+        fetchSpec: '*',
       },
       raw: 'git@npm:not-git',
     },
@@ -461,6 +461,33 @@ t.test('basic', function (t) {
       raw: 'file:/.path/to/foo',
     },
 
+    'file:./path/to/foo': {
+      name: null,
+      escapedName: null,
+      type: 'directory',
+      saveSpec: 'file:path/to/foo',
+      fetchSpec: '/test/a/b/path/to/foo',
+      raw: 'file:./path/to/foo',
+    },
+
+    'file:/./path/to/foo': {
+      name: null,
+      escapedName: null,
+      type: 'directory',
+      saveSpec: 'file:path/to/foo',
+      fetchSpec: '/test/a/b/path/to/foo',
+      raw: 'file:/./path/to/foo',
+    },
+
+    'file://./path/to/foo': {
+      name: null,
+      escapedName: null,
+      type: 'directory',
+      saveSpec: 'file:path/to/foo',
+      fetchSpec: '/test/a/b/path/to/foo',
+      raw: 'file://./path/to/foo',
+    },
+
     'file:../path/to/foo': {
       name: null,
       escapedName: null,
@@ -479,6 +506,15 @@ t.test('basic', function (t) {
       raw: 'file:/../path/to/foo',
     },
 
+    'file://../path/to/foo': {
+      name: null,
+      escapedName: null,
+      type: 'directory',
+      saveSpec: 'file:../path/to/foo',
+      fetchSpec: '/test/a/path/to/foo',
+      raw: 'file://../path/to/foo',
+    },
+
     'file:///path/to/foo': {
       name: null,
       escapedName: null,
@@ -517,6 +553,7 @@ t.test('basic', function (t) {
       escapedName: null,
       type: 'directory',
       saveSpec: 'file:',
+      fetchSpec: '/test/a/b',
       raw: 'file://.',
     },
 
@@ -550,9 +587,9 @@ t.test('basic', function (t) {
     foo: {
       name: 'foo',
       escapedName: 'foo',
-      type: 'tag',
+      type: 'range',
       saveSpec: null,
-      fetchSpec: 'latest',
+      fetchSpec: '*',
       raw: 'foo',
     },
 
